@@ -162,8 +162,8 @@ class AristaL3Driver(object):
         registry.subscribe(self.update_network, resources.NETWORK,
                            events.AFTER_UPDATE)
 
-    def update_subnet(self, resource, event, trigger, **kwargs):
-        subnet_info = kwargs['subnet']
+    def update_subnet(self, resource, event, trigger, payload):
+        subnet_info = payload.latest_state
 
         if subnet_info['ip_version'] == 6:
             LOG.info('IPv6 networks not supported with L3 plugin')
@@ -188,9 +188,8 @@ class AristaL3Driver(object):
             self._delete_default_gateway(router_name)
             self._add_network_default_gateway(network_id)
 
-    def update_network(self, resource, event, trigger, **kwargs):
-        network_info = kwargs['network']
-        self._reset_network_default_route(network_info['id'])
+    def update_network(self, resource, event, trigger, payload):
+        self._reset_network_default_route(payload.resource_id)
 
     def _prepare_network_default_gateway(self, network_id):
         router_info = db_lib.get_network_gateway_ipv4(network_id)
@@ -240,8 +239,8 @@ class AristaL3Driver(object):
             except ValueError:
                 self._raise_invalid_protected_vlans(vlan_string)
 
-            if not (const.MIN_VLAN_TAG <= min_vlan <= max_vlan <=
-                    const.MAX_VLAN_TAG):
+            if not (const.MIN_VLAN_TAG <= min_vlan <=
+                    max_vlan <= const.MAX_VLAN_TAG):
                 self._raise_invalid_protected_vlans(vlan_string)
             vlans.update(range(min_vlan, max_vlan + 1))
         return vlans
@@ -271,7 +270,7 @@ class AristaL3Driver(object):
             result = self._run_eos_cmds(cmds, host, log_exception=False,
                                         keep_alive=keep_alive,
                                         update_vrf_commands=False)
-            LOG.info('show version result %s' % result)
+            LOG.info(_LI('show version result %s'), result)
         except Exception:
             # We don't know what exception we got return None
             # At this moment we don't know what command we support for vrf
@@ -569,11 +568,15 @@ class AristaL3Driver(object):
             if self._mlag_configured:
                 # For MLAG, we send a specific IP address as opposed to cidr
                 # For now, we are using x.x.x.253 and x.x.x.254 as virtual IP
+                # unless either collides with the router interface fixed_ip,
+                # in which case we use x.x.x.252
                 mlag_peer_failed = False
+                router_ips = self._get_router_ips(cidr, len(self._servers),
+                                                  router_info['ip_version'],
+                                                  router_info['fixed_ip'])
                 for i, server in enumerate(self._servers):
                     # Get appropriate virtual IP address for this router
-                    router_ip = self._get_router_ip(cidr, i,
-                                                    router_info['ip_version'])
+                    router_ip = router_ips[i]
                     try:
                         self.add_interface_to_router(router_info['seg_id'],
                                                      router_name,
@@ -709,18 +712,17 @@ class AristaL3Driver(object):
         lo = bin_addr & 0xFFFFFFFF
         return socket.inet_ntop(socket.AF_INET6, struct.pack("!QQ", hi, lo))
 
-    def _get_router_ip(self, cidr, ip_count, ip_ver):
+    def _get_router_ips(self, cidr, ip_count, ip_ver, fixed_ip):
         """For a given IP subnet and IP version type, generate IP for router.
 
-        This method takes the network address (cidr) and selects an
-        IP address that should be assigned to virtual router running
+        This method takes the network address (cidr) and selects a set of
+        IP addresses that should be assigned to virtual router running
         on multiple switches. It uses upper addresses in a subnet address
         as IP for the router. Each instace of the router, on each switch,
         requires uniqe IP address. For example in IPv4 case, on a 255
         subnet, it will pick X.X.X.254 as first addess, X.X.X.253 for next,
-        and so on.
+        and so on, skipping an address specified as the reserved_ip
         """
-        start_ip = MLAG_SWITCHES + ip_count
         network_addr, prefix = cidr.split('/')
         if ip_ver == 4:
             bits = IPV4_BITS
@@ -733,10 +735,18 @@ class AristaL3Driver(object):
 
         network_addr = ip & mask
 
-        router_ip = pow(2, bits - int(prefix)) - start_ip
+        router_ips = list()
+        ip_idx = 0
+        while len(router_ips) < ip_count:
+            start_ip = MLAG_SWITCHES + ip_idx
+            router_ip = pow(2, bits - int(prefix)) - start_ip
 
-        router_ip = network_addr | router_ip
-        if ip_ver == 4:
-            return self._get_ipv4_from_binary(router_ip) + '/' + prefix
-        else:
-            return self._get_ipv6_from_binary(router_ip) + '/' + prefix
+            router_ip = network_addr | router_ip
+            if ip_ver == 4:
+                router_ip = self._get_ipv4_from_binary(router_ip)
+            else:
+                router_ip = self._get_ipv6_from_binary(router_ip)
+            ip_idx += 1
+            if router_ip != fixed_ip.lower():
+                router_ips.append(router_ip + '/' + prefix)
+        return router_ips
