@@ -85,8 +85,8 @@ class AristaHAScaleSimulationDriver(AristaHASimulationDriver):
         registry.subscribe(self._port_update_callback,
                            resources.PORT, events.AFTER_UPDATE)
 
-    def _port_update_callback(self, resource, event, trigger, **kwargs):
-        port = kwargs.get('port')
+    def _port_update_callback(self, resource, event, trigger, payload):
+        port = payload.latest_state
         host = port.get(portbindings.HOST_ID)
         vif_type = port.get(portbindings.VIF_TYPE)
         device_dict = {'device': port['id'],
