@@ -21,6 +21,7 @@ from eventlet import queue
 import mock
 from pstats import Stats
 
+from neutron_lib.api.definitions import l3 as l3_const
 from neutron_lib.api.definitions import portbindings
 from neutron_lib import constants as n_const
 import neutron_lib.context
@@ -176,6 +177,8 @@ class MechTestBase(test_plugin.Ml2PluginV2TestCase):
             rpc_plugin.update_device_down(context, **device_dict)
 
     def create_network(self, net_dict):
+        network = net_dict.get('network', {})
+        network['mtu'] = network.get('mtu', 1450)
         net = self.plugin.create_network(self.context, net_dict)
         self.plugin.create_subnet(self.context,
                                   {'subnet':
@@ -423,14 +426,18 @@ class L3HARouterTestFramework(MechTestBase):
         super(L3HARouterTestFramework, self).setUp()
         self.l3_plugin = directory.get_plugin(p_const.L3)
         self.l3_rpc_cb = l3_rpc.L3RpcCallback()
+        self.ext_net = None
 
-    def create_router(self, ha=False):
-        router = self.l3_plugin.create_router(
-            self.context, {'router': {'name': 'router',
-                                      'admin_state_up': True,
-                                      'tenant_id': self._tenant_id,
-                                      'ha': ha,
-                                      'distributed': False}})
+    def create_router(self, ha=False, ext_net=None):
+        router_dict = {'router': {'name': 'router',
+                                  'admin_state_up': True,
+                                  'tenant_id': self._tenant_id,
+                                  'ha': ha,
+                                  'distributed': False}}
+        if ext_net:
+            router_dict['router'][l3_const.EXTERNAL_GW_INFO] = {'network_id':
+                                                                ext_net['id']}
+        router = self.l3_plugin.create_router(self.context, router_dict)
         self.l3_plugin.schedule_router(self.context, router['id'])
         for host in self.l3_agents:
             self.sync_routers(router['id'], host['host'])
@@ -501,7 +508,7 @@ class L3HARouterTestFramework(MechTestBase):
 
         def resource_created():
             cvx_data = list(self.cvx.endpoint_data[endpoint].values())
-            expected_data = {'hostId': host,
+            expected_data = {'hostId': '(see router ports)',
                              'tenantId': router['project_id'],
                              'id': router['id']}
             return cvx_data and cvx_data[0] == expected_data
@@ -512,7 +519,7 @@ class L3HARouterTestFramework(MechTestBase):
 
         def resource_created():
             cvx_data = list(self.cvx.endpoint_data[endpoint].values())
-            expected_data = {'hostId': 'HA Router',
+            expected_data = {'hostId': '(see router ports)',
                              'tenantId': router['project_id'],
                              'id': router['id']}
             return cvx_data and cvx_data[0] == expected_data
